@@ -77,6 +77,7 @@
 #define USB_DEVICE_ID_RAZER_ORNATA_V2 0x025D
 #define USB_DEVICE_ID_RAZER_CYNOSA_V2 0x025E
 #define USB_DEVICE_ID_RAZER_HUNTSMAN_V2_ANALOG 0x0266
+#define USB_DEVICE_ID_RAZER_BLADE_LATE_2020_BASE 0x0268
 #define USB_DEVICE_ID_RAZER_HUNTSMAN_MINI_JP 0x0269
 #define USB_DEVICE_ID_RAZER_BOOK_2020 0x026A
 #define USB_DEVICE_ID_RAZER_HUNTSMAN_V2_TENKEYLESS 0x026B
@@ -111,6 +112,7 @@
 #define USB_DEVICE_ID_RAZER_ORNATA_V3_X_ALT 0x02A2
 #define USB_DEVICE_ID_RAZER_ORNATA_V3_TENKEYLESS 0x02A3
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_V4_75PCT 0x02A5
+#define USB_DEVICE_ID_RAZER_HUNTSMAN_V3_PRO 0x02A6
 #define USB_DEVICE_ID_RAZER_BLADE_14_2024 0x02B6
 #define USB_DEVICE_ID_RAZER_BLADE_18_2024 0x02B8
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_V3_TK 0x0A24
