@@ -87,6 +87,8 @@
 #define USB_DEVICE_ID_RAZER_COBRA 0x00A3
 #define USB_DEVICE_ID_RAZER_VIPER_V2_PRO_WIRED 0x00A5
 #define USB_DEVICE_ID_RAZER_VIPER_V2_PRO_WIRELESS 0x00A6
+#define USB_DEVICE_ID_RAZER_NAGA_V2_PRO_WIRED 0x00A7
+#define USB_DEVICE_ID_RAZER_NAGA_V2_PRO_WIRELESS 0x00A8
 #define USB_DEVICE_ID_RAZER_BASILISK_V3_PRO_WIRED 0x00AA
 #define USB_DEVICE_ID_RAZER_BASILISK_V3_PRO_WIRELESS 0x00AB
 #define USB_DEVICE_ID_RAZER_COBRA_PRO_WIRED 0x00AF
