@@ -8,6 +8,10 @@ MACRO_LED_BLINK = 0x01
 WAVE_RIGHT = 0x01
 WAVE_LEFT = 0x02
 
+# Wheel directions
+WHEEL_RIGHT = 0x01
+WHEEL_LEFT = 0x02
+
 # Reactive
 REACTIVE_500MS = 0x01
 REACTIVE_1000MS = 0x02
@@ -22,6 +26,7 @@ STARLIGHT_SLOW = 0x03
 # Ripple
 RIPPLE_REFRESH_RATE = 0.05
 
+# NOTE: These constants are deprecated. Use values from supported_poll_rates instead
 POLL_8000HZ = 8000
 POLL_4000HZ = 4000
 POLL_2000HZ = 2000
